==> ktorrent-3.1.2.tar.bz2: ktorrent-3.1.2/plugins/infowidget/availabilitychunkbar.h <==
/***************************************************************************
 *   Copyright (C) 2005-2007 by Joris Guisson                              *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#ifndef AVAILABILITYCHUNKBAR_H
#define AVAILABILITYCHUNKBAR_H

#include "chunkbar.h"

namespace kt
{
		
	/**
	@author Joris Guisson
	*/
	class AvailabilityChunkBar : public ChunkBar
	{
		Q_OBJECT
	public:
		AvailabilityChunkBar(QWidget* parent);
		virtual ~AvailabilityChunkBar();
	
		virtual const bt::BitSet & getBitSet() const;
	
	};
}

#endif

==> ktorrent_4.1.3.orig.tar.bz2: ktorrent-4.1.3/plugins/infowidget/availabilitychunkbar.h <==
/***************************************************************************
 *   Copyright (C) 2005-2007 by Joris Guisson                              *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#ifndef AVAILABILITYCHUNKBAR_H
#define AVAILABILITYCHUNKBAR_H

#include <torrent/chunkbar.h>

namespace kt
{
		
	/**
	@author Joris Guisson
	*/
	class AvailabilityChunkBar : public ChunkBar
	{
		Q_OBJECT
	public:
		AvailabilityChunkBar(QWidget* parent);
		virtual ~AvailabilityChunkBar();
	
		virtual const bt::BitSet & getBitSet() const;
	
		void setTC(bt::TorrentInterface* tc);
	private:
		bt::TorrentInterface* curr_tc;
	};
}

#endif
